#
# spec file for package diffoscope
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           diffoscope
Version:        85
Release:        lp150.1.4
Summary:        In-depth comparison of files, archives, and directories
License:        GPL-3.0+
Group:          Development/Languages/Python
Url:            https://diffoscope.org/
Source:         https://files.pythonhosted.org/packages/source/d/diffoscope/diffoscope-%{version}.tar.gz
BuildRequires:  python3-libarchive-c
BuildRequires:  python3-nose
BuildRequires:  python3-pytest
BuildRequires:  python3-python-magic
BuildRequires:  python3-setuptools
Requires:       python3-libarchive-c
Requires:       python3-python-magic
Requires:       python3-setuptools
# Tools required for proper function of this program
# for getfacl
Suggests:       acl
# for ar, readelf, objcopy and objdump
Suggests:       binutils
Suggests:       bzip2
# for img2txt
Suggests:       caca-utils
# for isoinfo
Suggests:       cdrkit-cdrtools-compat
# for cbfstool
Suggests:       coreboot-utils
# for stat
Suggests:       coreutils
Suggests:       cpio
# for cmp and diff
Suggests:       diffutils
# for lsattr
Suggests:       e2fsprogs
# for ppudump
Suggests:       fpc
# for msgunfmt
Suggests:       gettext-tools
# for ghc
Suggests:       ghc-compiler
Suggests:       gzip
# for pedump
Suggests:       mono-devel
Suggests:       pdftk
# for pdftotext
Suggests:       poppler-tools
# for RPM unpacking
Suggests:       python3-rpm
Suggests:       sqlite3
# for unsquashfs
Suggests:       squashfs
# for zipinfo
Suggests:       unzip
# for xxd
Suggests:       vim
Suggests:       xz
# currently missing:
# enjarify, javap, lipo, otool, showttf, sng
BuildArch:      noarch
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description
diffoscope will try to get to the bottom of what makes files or
directories different. It will recursively unpack archives of many kinds
and transform various binary formats into more human readable form to
compare them. It can compare two tarballs, ISO images, or PDF just as
easily.

It can be scripted through error codes, and a report can be produced
with the detected differences. The report can be text or HTML.
When no type of report has been selected, diffoscope defaults
to write a text report on the standard output.

diffoscope is developed as part of the `“reproducible builds” Debian
project <https://wiki.debian.org/ReproducibleBuilds>`_.
It is meant to be able to quickly understand why two builds of the same
package produce different outputs. diffoscope was previously named
debbindiff.

%prep
%setup -q

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
mv %{buildroot}%{_bindir}/diffoscope %{buildroot}%{_bindir}/diffoscope-%{py3_ver}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
ln -s -f %{_sysconfdir}/alternatives/diffoscope %{buildroot}%{_bindir}/diffoscope
touch %{buildroot}%{_sysconfdir}/alternatives/diffoscope

%post
%_sbindir/update-alternatives --install \
    %{_bindir}/diffoscope diffoscope %{_bindir}/diffoscope-%{py3_ver} 10

%postun
if [ "$1" = 0 ] ; then
    %_sbindir/update-alternatives --remove diffoscope %{_bindir}/diffoscope-%{py3_ver}
fi

# FIXME: tests are failing yet I don't think that problem is on our side
#%%check
#nosetests

%files
%defattr(-,root,root,-)
%doc COPYING README.rst
%{_bindir}/diffoscope
%{_bindir}/diffoscope-%{py3_ver}
%{python3_sitelib}/*
%ghost %{_sysconfdir}/alternatives/diffoscope

%changelog
* Wed Aug  2 2017 sleep_walker@opensuse.org
- Update to 85:
  see GIT log for full list of changes
* Tue Mar 14 2017 kgronlund@suse.com
- Update to 78:
  * Catch bad JSON errors on Python pre-3.5.  Closes: #855233
  * Correct logic of module_exists, ensuring we correctly skip in case of
    modules containing a dot in their name.  Closes: #854745
  * No need to track archive directory locations.
  * Add --exclude option.  Closes: #854783
  * When extracting archives, try to keep directory sizes small.
  * Extract archive members using an auto-incrementing integer, avoiding the
    need to sanitise filenames and avoiding writes to arbitrary locations.
    (Closes: #854723 * CVE-2017-0359)
  * Fix autopkgtest failures when Recommends are not installed.
    (Closes: #854593)
  * Specify <html lang="en"> in HTML output. (re. #849411)
  * Add a machine-readable JSON output format. (Closes: #850791)
  * Show results from debugging packages last. (Closes: #820427)
  * Add a --max-text-report-size option. (Closes: #851147)
    Clean all temp files in signal handler thread instead of attempting to
    bubble exception back to the main thread. (Closes: #852013)
  * Prevent FTBFS by loading fixtures as UTF-8 in case surrounding terminal
    is not Unicode-aware. (Closes: #852926)
  * Fix errors when comparing directories with non-directories.
    (Closes: #835641)
  * Fix behaviour of setting report maximums to zero (ie. no limits)
  * diffoscope.diff: Improve FIFO writing robustness.
  * haskell: Properly extract version from interface files.
  * Add markdown output support.  Closes: #848141
  * Add RestructuredText output format.
  * Improve --help output.  Closes: #852015
  * Don't blow up if directory containing ELF debug symbols already exists.
    (Closes: #850807)
  * Fix .APK extration when provided with absolute filenames.
    (Closes: #850485)
  * Support comparing .ico files using img2txt. (Closes: #850730)
  * comparators.utils.file: If we don't have an archive-extraction tool (eg.
    apktool), don't blow up when attempting to unpack it.
  * Include magic file type when we know the file format but can't find
    file-specific details. (Closes: #850850)
  * Ensure fake "APK metadata" file appears first, fixing non-deterministic
    tests/output.
  * Correctly escape value of href="" elements (re. #849411)
  * comparators/device: don't crash when comparing a non-device against a
    device (Closes: #850055)
  * Remove archive name from apktool.yml and rename it. (Closes: #850501)
  * Zipinfo included in APK files comparison. (Closes: #850502)
  * Add some tests for APK comparator.
  * Add image metadata comparison. (Closes: #849395)
  * Ensure imagemagick version is new enough for image metadata tests.
  * Extend .apk recognition regex to also match zip archives (Closes: #849638)
  * Update dex_expected_diffs and test requirement to ensure test compatibility
    with enjarify >= 1.0.3. (Closes: #849142)
  * Add detection of order-only difference in plain text format.
    (Closes: #848049)
  * Fix sqlite3 magic recognition when using file >= 5.27. (Closes: #830434)
  * Add argument completion feature to diffoscope. (Closes: #826711)
  * Improve message when data differs. (Closes: #827981)
  * Clarify the input arguments. (Closes: #826894)
  * Fix maybe_decode() so that it actually works.
* Thu Jun 23 2016 sleep_walker@opensuse.org
- update to 54:
  * In the directory comparator, fall back to current directory instead of
    empty name. (Closes: #820624)
  * Improve deb(5) support. (Closes: #818414)
  * debian/control: add myself to Uploaders.
  * Clean up temporary debuglink files.
  * Fix FileNotFoundError with broken symlinks. (Closes: #818856)
  * Decode Md5sumsFile in utf-8. (Closes: #823874)
  * Always suffix temporary files with '_diffoscope'.
  * Rewrite sanity check for the version to always run every time debian/rules
    is invoked, not only during a binary build.
  * Add FreeBSD packages for required tools.
  * Add README.rst to MANIFEST.in.
  * debian/gbp.conf: add a conf to have gbp tag the releases how we like them.
  * Drop transitional debbindiff package.
  * debian/control: Drop XS-Prefix from Testsuite: field, thanks lintian.
  * Mention --max-report-size only once in the manpage. (Closes: #819956)
  * Fix typo in documentation.
  * Bump Standards-Version to 3.9.8, no changes required.
  * Let objdump demangle symbols for better readability.
  * Install bin/diffoscope instead of auto-generated script. (Closes: #821777)
  * Team upload.
  * Re-upload, the last uploaded tarball was broken, missing test files.
  * Remove myself from uploaders
  * Show line ordering variation in deb md5sums
  * Reset mtimes of test directories and ignore ctimes (Closes: #815171)
  * Add comparator for Postscript files
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Sun Apr 10 2016 arun@gmx.de
- specfile:
  * fix update alternative (use %%{py3_ver}, touch sysconfig dir)
- update to version 51:
  * Team upload.
  * Re-upload, the last uploaded tarball was broken, missing test
    files.
- changes from version 50:
  * Remove myself from uploaders (Jérémy Bobbio)
  * Show line ordering variation in deb md5sums
  * Reset mtimes of test directories and ignore ctimes (Closes:
    [#815171])
  * Add comparator for Postscript files
* Sun Mar 13 2016 bwiedemann@suse.com
- We require python3-setuptools at runtime to work
* Thu Feb 18 2016 arun@gmx.de
- update to version 49:
  * Don't crash when we can't find the debug file in a matching debug
    package.  This repairs diffoscope for xserver-xorg and other
    packages.
  * Use libarchive to read metadata from ar archives. The output is
    more precise and less dependent on binutils version. The command
    line `ar` tool is not used any more so remove it from the required
    tools.
  * Split readelf --debug-dump output when examining ELF files. Based
    on a patch by Dhole.
  * Keep both .debug_str and .zdebug_str as ElfSection. Thanks to
    Niels Thykier for noticing the problem.
  * Fix a logic error in _install_debug_symbols. Thanks anthraxx for
    the report and the fix.
  * Use recursive containers for directory and only look at files with
    ending in .deb when looking for Build IDs. Both avoid looking at
    too many files when searching for matching debug packages. Thanks
    Helmut Grohne and Steven Chamberlain for the reports and
    tests. (Closes: #813052)
  * Add support for ICC profiles. This adds a Recommends on colord in
    Debian.
  * Harmonize spaces and commas in package list.
  * Update PPU files test data for FPC 3.0.0.
  * Update exepcted javap output for OpenJDK 1.8.
  * Stop specializing files from directories earlier than necessary.
  * Adding cd-iccdump package reference for Arch Linux.
  * Use HTTPS in Vcs-Git.
  * Bump standards version to 3.9.7, no changes needed.
  * Use /git/ instead /cgit/ in Vcs-Browser.
* Tue Feb  2 2016 sleep_walker@opensuse.org
- clean with spec-cleaner
- change Recommends: to Suggests:
- use update-alternatives mechanism for binary not to conflict with
  python2 variant of the package when there is one
* Sun Jan 31 2016 sleep_walker@opensuse.org
- add recommendations for tools which allows to interpret content
* Sun Jan 31 2016 sleep_walker@opensuse.org
- let there be diffoscope for openSUSE!
